@@ -1,16 +1,12 @@
 """`baselines.models` module."""
-from flexs.baselines.models.adaptive_ensemble import (  # noqa: F401
-    AdaptiveEnsemble,
-)
+from flexs.baselines.models.adaptive_ensemble import AdaptiveEnsemble  # noqa: F401
 from flexs.baselines.models.cnn import CNN  # noqa: F401
 from flexs.baselines.models.global_epistasis_model import (  # noqa: F401
     GlobalEpistasisModel,
 )
 from flexs.baselines.models.keras_model import KerasModel  # noqa: F401
 from flexs.baselines.models.mlp import MLP  # noqa: F401
-from flexs.baselines.models.noisy_abstract_model import (  # noqa: F401
-    NoisyAbstractModel,
-)
+from flexs.baselines.models.noisy_abstract_model import NoisyAbstractModel  # noqa: F401
 from flexs.baselines.models.sklearn_models import (  # noqa: F401
     LinearRegression,
     LogisticRegression,
