@@ -59,5 +59,9 @@ class CNN(keras_model.KerasModel):
             name = f"CNN_hidden_size_{hidden_size}_num_filters_{num_filters}"
 
         super().__init__(
-            model, alphabet=alphabet, name=name, batch_size=batch_size, epochs=epochs,
+            model,
+            alphabet=alphabet,
+            name=name,
+            batch_size=batch_size,
+            epochs=epochs,
         )
